boto v2.9.5 — boto v2.15.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.15.0 »

# boto v2.9.5

date: | 2013/05/28

This release adds support for web identity federation within the Secure Token Service (STS) & fixes several bugs.

## Features

- Added support for web identity federation - You can now delegate token access via either an Oauth 2.0 or OpenID provider. (commit 9bd0a3)

## Bugfixes

- Altered the S3 key buffer to be a configurable value. (issue 1506, commit 8e3e36)
- Added Sphinx extension for better release notes. (issue 1511, commit e2e32d & commit 3d998b)
- Fixed a bug where DynamoDB v2 would only ever connect to the default endpoint. (issue 1508, commit 139912)
- Fixed a iteration/empty results bug & a `between` bug in DynamoDB v2. (issue 1512, commit d109b6)
- Fixed an issue with `EbsOptimized` in EC2 Autoscale. (issue 1513, commit 424c41)
- Fixed a missing instance variable bug in DynamoDB v2. (issue 1516, commit 6fa8bf)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.15.0 »